@@ -1,6 +1,6 @@
 package App::dux;
 
-our $VERSION = '1.41'; # VERSION
+our $VERSION = '1.42'; # VERSION
 
 1;
 # ABSTRACT: Run Data::Unixish function on the command-line
@@ -17,7 +17,11 @@ App::dux - Run Data::Unixish function on the command-line
 
 =head1 VERSION
 
-version 1.41
+version 1.42
+
+=head1 RELEASE DATE
+
+2014-04-24
 
 =head1 HOMEPAGE
 
